﻿# pane Holynuv fontobasicator
# v1.00  13.03.2021 jindroush
# usage: fontobasicator.py fontfilename
# outputs Atari Basic listing as fontfilename.lst

import os.path
import struct
import sys
import array

if len(sys.argv) < 2:
    raise ValueError("Jmeno souboru s fontem musi byt jako prvni parametr.")

infile = sys.argv[1]

if os.path.isfile(infile):
    flen = os.stat(infile).st_size
    if flen == 1024:
        with open(infile, 'rb') as IN:
            file_content = IN.read(1024)
            IN.close()
    else:
        raise ValueError("Soubor '%s' s fontem nema 1024 bajtu!" % infile )
else:
    raise ValueError( "Soubor '%s' neexistuje." % infile )

pre, ext = os.path.splitext(infile)
outfile = pre + ".lst"
OUT = open( outfile, 'wb')

atari_eol = struct.pack('B', 0x9B)

line = 0
while file_content:
    my_str = file_content[0:0x68]
    file_content = file_content[len(my_str):]

    OUT.write( bytes( ("%d REM " % line), "utf-8" ))
    OUT.write(my_str)
    OUT.write(atari_eol)

    line += 1

"""
source of the usr code
	PLA		;number of args, always 0 in our case

	LDA	RAMTOP	;page where we are storing font
	STA	$CE     ;$CD - our destination
	INC	$CE

	LDA	#$00
	STA	$CD

	CLC		;$88 = STMTAB, where BASIC tokens are
	LDA	$88
	ADC	#$05	;skip first 5
	STA	$CB
	LDA	$89	
	ADC	#$00
	STA	$CC     ;copy this address to $CB - our source

	LDA	#$09    ;we process 10 rem lines
	STA	$CF

	LDX	#$68	;each rem contains $68 font bytes
	LDY	#$00
mainlp: LDA	($CB),Y
	STA	($CD),Y
	DEX	
	BNE	increms	;jump there if we have more bytes to process

	CLC		;one rem line finished
	LDA	$CB
	ADC	#$06	;jump over six bytes (eol + line no + rem)
	STA	$CB
	LDA	$CC
	ADC	#$00
	STA	$CC
	DEC	$CF	;decrement lines to process
	BEQ	lastl   ;is it last line?
	BMI	reta	;really last, return
	LDX	#$68	;each rem contains $68 font bytes

increms:INY	
	BNE	mainlp
	INC	$CC
	INC	$CE
	CLC	
	BCC	mainlp

lastl:	LDX	#$58	;the last line contains $58 bytes
	CLC	
	BCC	mainlp
reta:	RTS	

"""

rout = bytearray([
0x68, 0xA5, 0x6A, 0x85, 0xCE, 0xE6, 0xCE, 0xA9,
0x00, 0x85, 0xCD, 0x18, 0xA5, 0x88, 0x69, 0x05,
0x85, 0xCB, 0xA5, 0x89, 0x69, 0x00, 0x85, 0xCC,
0xA9, 0x09, 0x85, 0xCF, 0xA2, 0x68, 0xA0, 0x00,
0xB1, 0xCB, 0x91, 0xCD, 0xCA, 0xD0, 0x15, 0x18,
0xA5, 0xCB, 0x69, 0x06, 0x85, 0xCB, 0xA5, 0xCC,
0x69, 0x00, 0x85, 0xCC, 0xC6, 0xCF, 0xF0, 0x0E,
0x30, 0x11, 0xA2, 0x68, 0xC8, 0xD0, 0xE1, 0xE6,
0xCC, 0xE6, 0xCE, 0x18, 0x90, 0xDA, 0xA2, 0x58,
0x18, 0x90, 0xD5, 0x60 ])

OUT.write( b"10 POKE 106,PEEK(106)-5:GRAPHICS 0:R=(PEEK(106)+1):POKE 756,R" + atari_eol )
OUT.write( b"11 A=USR(ADR(\"" + rout + b"\"))" + atari_eol )
OUT.close()
